@@ -4,7 +4,7 @@ import pg8000
 
 def query(db_client, query_string):
 
-    print("QUERY: " + query_string)
+    #print("QUERY: " + query_string)
 
     try:
         with db_client.cursor() as cursor:
@@ -24,7 +24,7 @@ def query(db_client, query_string):
 
 def get_many(db_client, query_string):
 
-    print("GET MANY QUERY: " + query_string)
+    #print("GET MANY QUERY: " + query_string)
 
     try:
         with db_client.cursor() as cursor:
@@ -49,7 +49,7 @@ def get_many(db_client, query_string):
 
 def get_one(db_client, query_string):
 
-    print("GET ONE QUERY: " + query_string)
+    #print("GET ONE QUERY: " + query_string)
 
     try:
         with db_client.cursor() as cursor:
@@ -77,7 +77,7 @@ def get_many_list(db_client, query_list):
     result_list = []
     try:
         for query in query_list:
-            print("QUERY: " + query)
+            #print("QUERY: " + query)
             with db_client.cursor() as cursor:
                 cursor.execute(query)
 
